@@ -1,7 +1,13 @@
+import datetime
+from typing import List, Any, Union, Tuple, Callable, Dict
+
+import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 import seaborn as sns
+from mpl_toolkits.mplot3d import Axes3D
+
 from .config import Style
 from .utils import (
     looks_like_list_of_lists,
@@ -9,10 +15,6 @@ from .utils import (
     to_list_if_other_array,
     make_dict,
 )
-from typing import List, Any, Union, Tuple, Callable, Dict
-from mpl_toolkits.mplot3d import Axes3D
-import matplotlib
-import datetime
 
 
 ##################
@@ -93,7 +95,9 @@ def adjust_axes(
         if x_axis_formatter is None:
             x_axis_formatter: str = "%Y-%m-%d"
         xfmt = matplotlib.dates.DateFormatter(x_axis_formatter)
-        plt.gca().xaxis.set_major_formatter(xfmt)
+        ax = plt.gca()
+        ax.set_xticklabels(ax.get_xticks(), rotation=45)
+        ax.xaxis.set_major_formatter(xfmt)
 
 
 def apply_plot_labels(
